@@ -1,5 +1,5 @@
 core <- c("broom", "dials", "dplyr", "ggplot2", "infer", "parsnip",
-          "purrr", "recipes", "rsample", "tibble", "yardstick")
+          "purrr", "recipes", "rsample", "tibble", "tune", "workflows", "yardstick")
 
 pkg_loaded <- function(pkg = NULL) {
   if (is.null(pkg))
